@@ -1106,9 +1106,7 @@ func TestDefault(t *testing.T) {
 		Config: config.Project{
 			Dockers: []config.Docker{
 				{
-					IDs:      []string{"aa"},
-					Builds:   []string{"foo"},
-					Binaries: []string{"aaa"},
+					IDs: []string{"aa"},
 				},
 				{
 					Use: useBuildx,
@@ -1127,7 +1125,7 @@ func TestDefault(t *testing.T) {
 	docker := ctx.Config.Dockers[0]
 	require.Equal(t, "linux", docker.Goos)
 	require.Equal(t, "amd64", docker.Goarch)
-	require.Equal(t, []string{"aa", "foo"}, docker.IDs)
+	require.Equal(t, []string{"aa"}, docker.IDs)
 	require.Equal(t, useDocker, docker.Use)
 	docker = ctx.Config.Dockers[1]
 	require.Equal(t, useBuildx, docker.Use)
@@ -1138,6 +1136,27 @@ func TestDefault(t *testing.T) {
 	require.Equal(t, useDocker, ctx.Config.DockerManifests[1].Use)
 }
 
+func TestDefaultDuplicateID(t *testing.T) {
+	ctx := &context.Context{
+		Config: config.Project{
+			Dockers: []config.Docker{
+				{ID: "foo"},
+				{ /* empty */ },
+				{ID: "bar"},
+				{ID: "foo"},
+			},
+			DockerManifests: []config.DockerManifest{
+				{ID: "bar"},
+				{ /* empty */ },
+				{ID: "bar"},
+				{ID: "foo"},
+			},
+		},
+	}
+	require.EqualError(t, Pipe{}.Default(ctx), "found 2 dockers with the ID 'foo', please fix your config")
+	require.EqualError(t, ManifestPipe{}.Default(ctx), "found 2 docker_manifests with the ID 'bar', please fix your config")
+}
+
 func TestDefaultInvalidUse(t *testing.T) {
 	ctx := &context.Context{
 		Config: config.Project{
